﻿using System;
using System.Collections.Generic;
using System.Windows;

namespace ObjectLibrary
{
    class Alert
    {
        public string Name { get; set; }
        public string Title { get; set; }
        public string Text { get; set; }
        public MessageBoxButton Buttons { get; set; }
        public MessageBoxImage Icon { get; set; }
    }

    class AlertManager
    {
        // List of alerts
        private static Dictionary<string, Alert> _alerts = new Dictionary<string, Alert>();

        public static Dictionary<string, Alert> Alerts
        {
            get { return _alerts; }
        }

        // Add a new alert
        public static void Add(string name, string title, string text, MessageBoxButton buttons,
            MessageBoxImage icon)
        {
            _alerts.Add(name, new Alert()
            {
                Name = name, Title = title, Text = text, Buttons = buttons, Icon = icon
            });
        }

        // Find alert by name
        public static Alert Find(string name)
        {
            Alert alert = null;

            if (name != null)
            {
                try
                {
                    alert = Alerts[name];
                }
                catch (KeyNotFoundException) { }
            }

            return alert;
        }

        // Show alert by name
        public static MessageBoxResult Show(string name)
        {
            return Show(Find(name));
        }

        // Show alert by id
        public static MessageBoxResult Show(Alert alert)
        {
            if( alert != null)
                return MessageBox.Show(alert.Text, alert.Title, alert.Buttons, alert.Icon);

            return MessageBoxResult.Cancel;
        }
    }
}
